/**
  *  \file game/backup.h
  *  \brief Backup File Creation
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_BACKUP_H
#define PCC_V2_GAME_BACKUP_H

#include "cpluslib/string.h"

class Stream;
class ProgressMonitor;
class ConfigStringOption;

extern ConfigStringOption opt_BackupTurn;
extern ConfigStringOption opt_BackupResult;
extern ConfigStringOption opt_BackupUtil;
extern ConfigStringOption opt_BackupChart;
extern ConfigStringOption opt_BackupScript;
// extern ConfigStringOption opt_UnpackSource;
extern ConfigStringOption opt_MaketurnTarget;

/** Backup file creation. This contains the logic to expand backup file path specifications,
    and to create the backup files. */
class GBackupFileTemplate {
 public:
    GBackupFileTemplate();

    // Configuration
    void setGameDirectory(string_t dir);
    void setPlayerNumber(int n);
    void setTurnNumber(int n);

    // Templates & Backups
    string_t expandFileName(string_t tpl);
    void copyFile(string_t tpl, Stream& src, ProgressMonitor& pm);
    void eraseFile(string_t tpl);

 private:
    string_t game_dir;
    int player_nr;
    int turn_nr;
};

/** Set directory name for '%d' variable.
    \param dir Name of directory */
inline void
GBackupFileTemplate::setGameDirectory(string_t dir)
{
    this->game_dir = dir;
}

/** Set player number for '%p' variable.
    \param n Player number */
inline void
GBackupFileTemplate::setPlayerNumber(int n)
{
    this->player_nr = n;
}

/** Set turn number for '%t' variable.
    \param n Turn number */
inline void
GBackupFileTemplate::setTurnNumber(int n)
{
    this->turn_nr = n;
}

#endif
