/**
  *  \file u/t_util_idalloc.cc
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "util/idalloc.h"
#include "u/t_util.h"

void
UtilIdAllocTestSuite::testIdAlloc()
{
    IdAllocator<int,int> x;

    int id_one   = x.addObject(47);
    int id_two   = x.addObject(11);
    int id_three = x.addObject(42);
    TS_ASSERT_DIFFERS(id_one, id_two);
    TS_ASSERT_DIFFERS(id_two, id_three);
    TS_ASSERT_DIFFERS(id_three, id_one);
    TS_ASSERT_DIFFERS(id_one, x.nil);
    TS_ASSERT_DIFFERS(id_two, x.nil);
    TS_ASSERT_DIFFERS(id_three, x.nil);

    TS_ASSERT_EQUALS(x.getObject(id_one), 47);
    TS_ASSERT_EQUALS(x.getObject(id_two), 11);
    TS_ASSERT_EQUALS(x.getObject(id_three), 42);

    // we cannot test anything else without violating IdAllocator's
    // invariants. But at least we can test that it does not crash.
    x.removeObject(id_three);
    x.removeObject(id_one);
    x.removeObject(id_two);
}
